@@ -51,7 +51,7 @@ class TestValidation(unittest.TestCase):
 
     def tearDown(self):
         self._create_object_fun = None
-        CONF.set_override('allow_cluster_ops', False)
+        CONF.clear_override('allow_cluster_ops')
 
     @patch("savanna.utils.api.bad_request")
     @patch("savanna.utils.api.request_data")
@@ -124,9 +124,14 @@ class TestValidation(unittest.TestCase):
         get_templates_p = patch("savanna.service.api.get_node_templates")
         get_template_p = patch("savanna.service.api.get_node_template")
         get_types_p = patch("savanna.service.api.get_node_types")
+        get_node_type_required_params_p = \
+            patch("savanna.service.api.get_node_type_required_params")
+        get_node_type_all_params_p = \
+            patch("savanna.service.api.get_node_type_all_params")
         patchers = (request_data_p, bad_req_p, not_found_p, int_err_p,
                     get_clusters_p, get_templates_p, get_template_p,
-                    get_types_p)
+                    get_types_p, get_node_type_required_params_p,
+                    get_node_type_all_params_p)
 
         request_data = request_data_p.start()
         bad_req = bad_req_p.start()
@@ -136,6 +141,8 @@ class TestValidation(unittest.TestCase):
         get_templates = get_templates_p.start()
         get_template = get_template_p.start()
         get_types = get_types_p.start()
+        get_node_type_required_params = get_node_type_required_params_p.start()
+        get_node_type_all_params = get_node_type_all_params_p.start()
 
         # stub clusters list
         get_clusters.return_value = getattr(self, "_clusters_data", [
@@ -162,9 +169,9 @@ class TestValidation(unittest.TestCase):
             })
         ])
 
-        def _get_template(**kwargs):
+        def _get_template(name):
             for template in get_templates():
-                if template.name == kwargs['name']:
+                if template.name == name:
                     return template
             return None
 
@@ -177,6 +184,20 @@ class TestValidation(unittest.TestCase):
             })
         ])
 
+        def _get_r_params(name):
+            if name == "JT+NN":
+                return {"job_tracker": ["jt_param"]}
+            return dict()
+
+        get_node_type_required_params.side_effect = _get_r_params
+
+        def _get_all_params(name):
+            if name == "JT+NN":
+                return {"job_tracker": ["jt_param"]}
+            return dict()
+
+        get_node_type_all_params.side_effect = _get_all_params
+
         # mock function that should be validated
         m_func = Mock()
         m_func.__name__ = "m_func"
@@ -184,7 +205,7 @@ class TestValidation(unittest.TestCase):
         # request data to validate
         request_data.return_value = data
 
-        v.validate(self._create_object_fun)(m_func)(id="some-id")
+        v.validate(self._create_object_fun)(m_func)()
 
         self.assertEqual(request_data.call_count, 1)
 
@@ -201,19 +222,19 @@ class TestValidation(unittest.TestCase):
         self._assert_create_object_validation(
             {},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'cluster' is required property")
+                       u"'cluster' is a required property")
         )
         self._assert_create_object_validation(
             {"cluster": {}},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'name' is required property")
+                       u"'name' is a required property")
         )
         self._assert_create_object_validation(
             {"cluster": {
                 "name": "some-name"
             }},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'base_image_id' is required property")
+                       u"'base_image_id' is a required property")
         )
         self._assert_create_object_validation(
             {"cluster": {
@@ -221,10 +242,10 @@ class TestValidation(unittest.TestCase):
                 "base_image_id": "some-image-id"
             }},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'node_templates' is required property")
+                       u"'node_templates' is a required property")
         )
 
-    def test_cluster_create_v_name(self):
+    def test_cluster_create_v_name_base(self):
         self._create_object_fun = v.validate_cluster_create
 
         cluster = {
@@ -244,11 +265,21 @@ class TestValidation(unittest.TestCase):
                        u"'' is too short")
         )
         self._assert_create_object_validation(
-            _cluster(cluster, name="a" * 241),
+            _cluster(cluster, name="a" * 51),
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'%s' is too long" % ('a' * 241))
+                       u"'%s' is too long" % ('a' * 51))
         )
 
+    def test_cluster_create_v_name_pattern(self):
+        self._create_object_fun = v.validate_cluster_create
+
+        cluster = {
+            "cluster": {
+                "base_image_id": "some-image-id",
+                "node_templates": {}
+            }
+        }
+
         def _assert_cluster_name_pattern(self, name):
             cluster_schema = v.CLUSTER_CREATE_SCHEMA['properties']['cluster']
             name_p = cluster_schema['properties']['name']['pattern']
@@ -263,6 +294,16 @@ class TestValidation(unittest.TestCase):
         _assert_cluster_name_pattern(self, "123")
         _assert_cluster_name_pattern(self, "asd?")
 
+    def test_cluster_create_v_name_exists(self):
+        self._create_object_fun = v.validate_cluster_create
+
+        cluster = {
+            "cluster": {
+                "base_image_id": "some-image-id",
+                "node_templates": {}
+            }
+        }
+
         self._assert_create_object_validation(
             _cluster(cluster, name="some-cluster-1"),
             bad_req_i=(1, "CLUSTER_NAME_ALREADY_EXISTS",
@@ -311,19 +352,19 @@ class TestValidation(unittest.TestCase):
         self._assert_create_object_validation(
             {},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'node_template' is required property")
+                       u"'node_template' is a required property")
         )
         self._assert_create_object_validation(
             {"node_template": {}},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'name' is required property")
+                       u"'name' is a required property")
         )
         self._assert_create_object_validation(
             {"node_template": {
                 "name": "some-name"
             }},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'node_type' is required property")
+                       u"'node_type' is a required property")
         )
         self._assert_create_object_validation(
             {"node_template": {
@@ -331,7 +372,7 @@ class TestValidation(unittest.TestCase):
                 "node_type": "some-node-type"
             }},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'flavor_id' is required property")
+                       u"'flavor_id' is a required property")
         )
         self._assert_create_object_validation(
             {"node_template": {
@@ -340,7 +381,7 @@ class TestValidation(unittest.TestCase):
                 "flavor_id": "flavor-1"
             }},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'name_node' is required property")
+                       u"'name_node' is a required property")
         )
         self._assert_create_object_validation(
             {"node_template": {
@@ -350,7 +391,7 @@ class TestValidation(unittest.TestCase):
                 "name_node": {}
             }},
             bad_req_i=(1, "VALIDATION_ERROR",
-                       u"'job_tracker' is required property")
+                       u"'job_tracker' is a required property")
         )
         self._assert_create_object_validation(
             {"node_template": {
@@ -359,7 +400,43 @@ class TestValidation(unittest.TestCase):
                 "flavor_id": "flavor-1",
                 "name_node": {},
                 "job_tracker": {}
-            }}
+            }},
+            bad_req_i=(1, "REQUIRED_PARAM_MISSED",
+                       u"Required parameter 'jt_param' of process "
+                       u"'job_tracker' should be specified")
+        )
+        self._assert_create_object_validation(
+            {"node_template": {
+                "name": "some-name",
+                "node_type": "JT+NN",
+                "flavor_id": "flavor-1",
+                "name_node": {},
+                "job_tracker": {"jt_param": ""}
+            }},
+            bad_req_i=(1, "REQUIRED_PARAM_MISSED",
+                       u"Required parameter 'jt_param' of process "
+                       u"'job_tracker' should be specified")
+        )
+        self._assert_create_object_validation(
+            {"node_template": {
+                "name": "some-name",
+                "node_type": "JT+NN",
+                "flavor_id": "flavor-1",
+                "name_node": {},
+                "job_tracker": {"jt_param": "some value", "bad.parameter": "1"}
+            }},
+            bad_req_i=(1, "PARAM_IS_NOT_ALLOWED",
+                       u"Parameter 'bad.parameter' "
+                       u"of process 'job_tracker' is not allowed to change")
+        )
+        self._assert_create_object_validation(
+            {"node_template": {
+                "name": "some-name",
+                "node_type": "JT+NN",
+                "flavor_id": "flavor-1",
+                "name_node": {},
+                "job_tracker": {"jt_param": "some value"}
+            }},
         )
         self._assert_create_object_validation(
             {"node_template": {
@@ -375,7 +452,7 @@ class TestValidation(unittest.TestCase):
                        u"Required: ['name_node', 'job_tracker']")
         )
 
-    def test_node_template_create_v_name(self):
+    def test_node_template_create_v_name_base(self):
         self._create_object_fun = v.validate_node_template_create
 
         template = {
@@ -402,6 +479,18 @@ class TestValidation(unittest.TestCase):
                        u"'%s' is too long" % ('a' * 241))
         )
 
+    def test_node_template_create_v_name_pattern(self):
+        self._create_object_fun = v.validate_node_template_create
+
+        template = {
+            "node_template": {
+                "node_type": "JT+NN",
+                "flavor_id": "flavor-1",
+                "name_node": {},
+                "job_tracker": {}
+            }
+        }
+
         def _assert_template_name_pattern(self, name):
             schema_props = v.TEMPLATE_CREATE_SCHEMA['properties']
             template_schema = schema_props['node_template']
@@ -417,6 +506,18 @@ class TestValidation(unittest.TestCase):
         _assert_template_name_pattern(self, "123")
         _assert_template_name_pattern(self, "asd?")
 
+    def test_node_template_create_v_name_exists(self):
+        self._create_object_fun = v.validate_node_template_create
+
+        template = {
+            "node_template": {
+                "node_type": "JT+NN",
+                "flavor_id": "flavor-1",
+                "name_node": {},
+                "job_tracker": {}
+            }
+        }
+
         self._assert_create_object_validation(
             _template(template, name="jt_nn.small"),
             bad_req_i=(1, "NODE_TEMPLATE_ALREADY_EXISTS",
